==> e107-0.7.20.tbz: www/e107/e107_languages/English/lan_upload.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_upload.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Upload");

define('LAN_UL_001','Invalid email address');
define('LAN_UL_002', 'You do not have the correct permissions to upload files to this server.');	// LAN_403

define('LAN_UL_020', 'Error');
define('LAN_UL_021', 'Upload Failure');

define('LAN_UL_032', 'You must select a category');
define('LAN_UL_033', 'You must enter a valid email address');
define('LAN_UL_034', 'You must specify the file name');
define('LAN_UL_035', 'You must enter a description');
define('LAN_UL_036', 'You must specify the file to upload');
define('LAN_UL_037', 'You must specify a category');
define('LAN_UL_038', '');

define("LAN_61", "Your Name: ");
define("LAN_112", "Email Address: ");
define("LAN_144", "Website URL: ");
define("LAN_402", "You must be a registered member to upload files to this server.");
define("LAN_404", "Thank you. Your upload will be reviewed by an administrator and posted to the site if appropriate.");
//define("LAN_405", "File exceeds specified maximum size limit - deleted.");
define("LAN_406", "Please note");
define("LAN_407", "Any other filetypes uploaded will be instantly deleted.");
define("LAN_408", "Underlined");
define("LAN_409", "Name of file");
define("LAN_410", "Version");
define("LAN_411", "File");
define("LAN_412", "Screenshot");
define("LAN_413", "Description");
define("LAN_414", "Working demo");
define("LAN_415", "enter URL to site where demo can be viewed");
define("LAN_416", "Submit and Upload");
define("LAN_417", "Upload File");
define("LAN_418", "Maximum file size: ");
define("DOWLAN_11", "Category");
define("LAN_419", "Allowed filetypes");
define("LAN_420", "fields are required");



?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/lan_upload.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_upload.php $
|     $Revision: 11678 $
|     $Id: lan_upload.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Upload");

define('LAN_UL_001','Invalid email address');
define('LAN_UL_002', 'You do not have the correct permissions to upload files to this server.');	// LAN_403

define('LAN_UL_020', 'Error');
define('LAN_UL_021', 'Upload Failure');

define('LAN_UL_032', 'You must select a category');
define('LAN_UL_033', 'You must enter a valid email address');
define('LAN_UL_034', 'You must specify the file name');
define('LAN_UL_035', 'You must enter a description');
define('LAN_UL_036', 'You must specify the file to upload');
define('LAN_UL_037', 'You must specify a category');
define('LAN_UL_038', '');

define("LAN_61", "Your Name: ");
define("LAN_112", "Email Address: ");
define("LAN_144", "Website URL: ");
define("LAN_402", "You must be a registered member to upload files to this server.");
define("LAN_404", "Thank you. Your upload will be reviewed by an administrator and posted to the site if appropriate.");
//define("LAN_405", "File exceeds specified maximum size limit - deleted.");
define("LAN_406", "Please note");
define("LAN_407", "Any other filetypes uploaded will be instantly deleted.");
define("LAN_408", "Underlined");
define("LAN_409", "Name of file");
define("LAN_410", "Version");
define("LAN_411", "File");
define("LAN_412", "Screenshot");
define("LAN_413", "Description");
define("LAN_414", "Working demo");
define("LAN_415", "enter URL to site where demo can be viewed");
define("LAN_416", "Submit and Upload");
define("LAN_417", "Upload File");
define("LAN_418", "Maximum file size: ");
define("DOWLAN_11", "Category");
define("LAN_419", "Allowed filetypes");
define("LAN_420", "fields are required");



?>
